<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vagamondo_enqueue_scripts')) {

	function vagamondo_enqueue_scripts() {

		wp_deregister_style( 'avventura-lite-style' );
		wp_deregister_style( 'avventura-lite-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) );

		wp_enqueue_style( 'avventura-lite-parent-style' , get_template_directory_uri() . '/style.css' ); 

		wp_enqueue_style(
			'vagamondo-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) . '.css',
			array( 'vagamondo-style' ),
			'1.0.0'
		); 

		wp_enqueue_style( 'vagamondo-style' , get_stylesheet_directory_uri() . '/style.css' ); 

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i'),
			'subset' =>	'latin,latin-ext'
		);
		
		wp_deregister_style('google-fonts');
		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

		wp_enqueue_script(
			'vagamondo-script',
			get_stylesheet_directory_uri() . '/assets/js/script.js',
			array('jquery'),
			'1.0.0', 
			TRUE
		);

	}
	
	add_action( 'wp_enqueue_scripts', 'vagamondo_enqueue_scripts', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vagamondo_replace_hooks')) {

	function vagamondo_replace_hooks() {

		remove_action( 'avventura_lite_top_sidebar', 'avventura_lite_top_sidebar_function' );
		remove_action( 'avventura_lite_header_sidebar', 'avventura_lite_header_sidebar_function' );
		remove_action( 'avventura_lite_slick_slider', 'avventura_lite_slick_slider_function', 10, 2);
		remove_action( 'avventura_lite_thumbnail', 'avventura_lite_thumbnail_function');
		remove_action( 'avventura_lite_after_content', 'avventura_lite_after_content_function' );
		remove_action( 'avventura_lite_default_format', 'avventura_lite_default_format_function' );
		remove_action( 'avventura_lite_image_format', 'avventura_lite_image_format_function' );
		remove_action( 'avventura_lite_page_format', 'avventura_lite_page_format_function' );
		
	}
	
	add_action('init','vagamondo_replace_hooks');

}

/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vagamondo_customize_register')) {

	function vagamondo_customize_register( $wp_customize ) {

		$wp_customize->remove_section( 'slideshow_section');

		$wp_customize->remove_control( 'avventura_lite_header_layout');
		$wp_customize->remove_control( 'avventura_lite_homepage_slideshow');
		$wp_customize->remove_control( 'avventura_lite_slideshow_limit');
		$wp_customize->remove_control( 'avventura_lite_homepage_slideshow_position');
		$wp_customize->remove_control( 'avventura_lite_slideshow_post_category');
		$wp_customize->remove_control( 'avventura_lite_slideshow_post_details');
		$wp_customize->remove_control( 'avventura_lite_slideshow_overlay');
		$wp_customize->remove_control( 'avventura_lite_post_icon');

		$wp_customize->add_setting( 'vagamondo_logo_text_color', array(
			'default' => '#ffffff',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( 'vagamondo_logo_text_color' , array(
			'type' => 'color',
			'section' => 'colors',
			'label' => esc_html__('Logo text color','vagamondo'),
			'description' => esc_html__('Choose your custom color for the logo.','vagamondo'),
		));
		
		$wp_customize->remove_control( 'avventura_lite_menu_font_weight');
		$wp_customize->add_control( 'avventura_lite_menu_font_weight' , array(
			'type' => 'select',
			'section' => 'menu_section',
			'label' => esc_html__('Menu weight','vagamondo'),
			'description' => esc_html__('Choose a font weight for the menu.','vagamondo'),
			'choices'  => array (
				'300' => esc_html__( '300','vagamondo'),
				'400' => esc_html__( '400','vagamondo'),
				'500' => esc_html__( '500','vagamondo'),
				'600' => esc_html__( '600','vagamondo'),
				'700' => esc_html__( '700','vagamondo'),
				'800' => esc_html__( '800','vagamondo'),
				'900' => esc_html__( '900','vagamondo'),
			),
		));

		$wp_customize->remove_control( 'avventura_lite_titles_font_weight');
		$wp_customize->add_control( 'avventura_lite_titles_font_weight' , array(
			'type' => 'select',
			'section' => 'headlines_section',
			'label' => esc_html__('Titles weight','vagamondo'),
			'description' => esc_html__('Choose a font weight for the titles.','vagamondo'),
			'choices'  => array (
				'300' => esc_html__( '300','vagamondo'),
				'400' => esc_html__( '400','vagamondo'),
				'500' => esc_html__( '500','vagamondo'),
				'600' => esc_html__( '600','vagamondo'),
				'700' => esc_html__( '700','vagamondo'),
				'800' => esc_html__( '800','vagamondo'),
				'900' => esc_html__( '900','vagamondo'),
			),
		));

		$wp_customize->add_setting( 'vagamondo_post_date', array(
			'default' => 'on',
			'sanitize_callback' => 'vagamondo_select_sanitize',
		));

		$wp_customize->add_control( 'vagamondo_post_date' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Post date', 'vagamondo'),
			'description' => esc_html__('Do you want to display the post date?', 'vagamondo'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'vagamondo'),
				'on' => esc_html__( 'Yes', 'vagamondo'),
			),
		));

		$wp_customize->add_setting( 'vagamondo_post_author', array(
			'default' => 'on',
			'sanitize_callback' => 'vagamondo_select_sanitize',
		));

		$wp_customize->add_control( 'vagamondo_post_author' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Post author', 'vagamondo'),
			'description' => esc_html__('Do you want to display the post author?', 'vagamondo'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'vagamondo'),
				'on' => esc_html__( 'Yes', 'vagamondo'),
			),
		));

		$wp_customize->add_control( 'avventura_lite_post_icon' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Post icon', 'vagamondo'),
			'description' => esc_html__('Do you want to display the post icon?', 'vagamondo'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'vagamondo'),
				'on' => esc_html__( 'Yes', 'vagamondo'),
			),
		));

		$wp_customize->add_setting( 'vagamondo_post_category', array(
			'default' => 'on',
			'sanitize_callback' => 'vagamondo_select_sanitize',
		));

		$wp_customize->add_control( 'vagamondo_post_category' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Post category', 'vagamondo'),
			'description' => esc_html__('Do you want to display the post category?', 'vagamondo'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'vagamondo'),
				'on' => esc_html__( 'Yes', 'vagamondo'),
			),
		));
		
		$wp_customize->add_panel( 'vagamondo_featured_area_panel', array(
			'title' => esc_html__( 'Vagamondo Featured Area','vagamondo'),
			'description' => esc_html__( 'Vagamondo Featured Area','vagamondo'),
			'priority' => 10,
		));

		$wp_customize->add_section( 'vagamondo_featured_area_settings', array(
			'title' => esc_html__( 'Settings','vagamondo'),
			'panel' => 'vagamondo_featured_area_panel',
			'priority' => 10,
			'description' => esc_html__('Settings','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_sticky_post_grid', array(
			'default' => 'on',
			'sanitize_callback' => 'vagamondo_select_sanitize',

		));

		$wp_customize->add_control( 'vagamondo_sticky_post_grid' , array(
			'type' => 'select',
			'priority' => '09',
			'section' => 'vagamondo_featured_area_settings',
			'label' => esc_html__('Sticky post grid','vagamondo'),
			'description' => esc_html__('Do you want to enable the sticky post grid section on homepage?.','vagamondo'),
			'choices'  => array (
			   'off' => esc_html__( 'No','vagamondo'),
			   'on' => esc_html__( 'Yes','vagamondo'),
			),
		));
		
		$wp_customize->add_setting( 'vagamondo_sticky_slideshow', array(
			'default' => 'on',
			'sanitize_callback' => 'vagamondo_select_sanitize',

		));

		$wp_customize->add_control( 'vagamondo_sticky_slideshow' , array(
			'type' => 'select',
			'priority' => '09',
			'section' => 'vagamondo_featured_area_settings',
			'label' => esc_html__('Slideshow position in mobile devices.','vagamondo'),
			'description' => esc_html__('Do you want to display the slideshow above the sticky posts in mobile devices?.','vagamondo'),
			'choices'  => array (
			   'off' => esc_html__( 'No','vagamondo'),
			   'on' => esc_html__( 'Yes','vagamondo'),
			),
		));
		
		$wp_customize->add_setting( 'vagamondo_enable_featuredlinks_section', array(
			'default' => 'off',
			'sanitize_callback' => 'vagamondo_select_sanitize',

		));

		$wp_customize->add_control( 'vagamondo_enable_featuredlinks_section' , array(
			'type' => 'select',
			'priority' => '09',
			'section' => 'vagamondo_featured_area_settings',
			'label' => esc_html__('Featured links section','vagamondo'),
			'description' => esc_html__('Do you want to enable the featured links section on homepage? (Once this option is activated, it is necessary to configure each link, returning to the previous section).','vagamondo'),
			'choices'  => array (
			   'off' => esc_html__( 'No','vagamondo'),
			   'on' => esc_html__( 'Yes','vagamondo'),
			),
		));

		$wp_customize->add_section( 'vagamondo_featured_link_1', array(
			'title' => esc_html__( 'Featured Link #1','vagamondo'),
			'panel' => 'vagamondo_featured_area_panel',
			'priority' => 10,
			'description' => esc_html__('Featured Link #1','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_featured_link_1_image', array(
			'default' => '',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'absint' 
		));
	
		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control($wp_customize, 'vagamondo_featured_link_1_image', array(
			'label' => esc_html__( 'Image','vagamondo'),
			'mime_type' => 'image',
			'description' => esc_html__( 'Upload the image','vagamondo'),
			'section' => 'vagamondo_featured_link_1',
			'settings' => 'vagamondo_featured_link_1_image',
			'width' => 940,
			'height' => 627,
		)));

		$wp_customize->add_setting( 'vagamondo_featured_link_1_title', array(
			'default' => '',
			'sanitize_callback' => 'sanitize_text_field',
		));

		$wp_customize->add_control( 'vagamondo_featured_link_1_title' , array(
			'type' => 'text',
			'section' => 'vagamondo_featured_link_1',
			'label' => esc_html__('Title','vagamondo'),
			'description' => esc_html__('Insert the title of this slide','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_featured_link_1_url', array(
			'default' => '',
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'vagamondo_featured_link_1_url' , array(
			'type' => 'url',
			'section' => 'vagamondo_featured_link_1',
			'label' => esc_html__('Url','vagamondo'),
			'description' => esc_html__('Insert the url of this slide','vagamondo'),
		));

		$wp_customize->add_section( 'vagamondo_featured_link_2', array(
			'title' => esc_html__( 'Featured Link #2','vagamondo'),
			'panel' => 'vagamondo_featured_area_panel',
			'priority' => 11,
			'description' => esc_html__('Featured Link #2','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_featured_link_2_image', array(
			'default' => '',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'absint' 
		));
	
		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control($wp_customize, 'vagamondo_featured_link_2_image', array(
			'label' => esc_html__( 'Image','vagamondo'),
			'mime_type' => 'image',
			'description' => esc_html__( 'Upload the image','vagamondo'),
			'section' => 'vagamondo_featured_link_2',
			'settings' => 'vagamondo_featured_link_2_image',
			'width' => 940,
			'height' => 627,
		)));

		$wp_customize->add_setting( 'vagamondo_featured_link_2_title', array(
			'default' => '',
			'sanitize_callback' => 'sanitize_text_field',
		));

		$wp_customize->add_control( 'vagamondo_featured_link_2_title' , array(
			'type' => 'text',
			'section' => 'vagamondo_featured_link_2',
			'label' => esc_html__('Title','vagamondo'),
			'description' => esc_html__('Insert the title of this slide','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_featured_link_2_url', array(
			'default' => '',
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'vagamondo_featured_link_2_url' , array(
			'type' => 'url',
			'section' => 'vagamondo_featured_link_2',
			'label' => esc_html__('Url','vagamondo'),
			'description' => esc_html__('Insert the url of this slide','vagamondo'),
		));

		$wp_customize->add_section( 'vagamondo_featured_link_3', array(
			'title' => esc_html__( 'Featured Link #3','vagamondo'),
			'panel' => 'vagamondo_featured_area_panel',
			'priority' => 12,
			'description' => esc_html__('Featured Link #3','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_featured_link_3_image', array(
			'default' => '',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'absint' 
		));
	
		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control($wp_customize, 'vagamondo_featured_link_3_image', array(
			'label' => esc_html__( 'Image','vagamondo'),
			'mime_type' => 'image',
			'description' => esc_html__( 'Upload the image','vagamondo'),
			'section' => 'vagamondo_featured_link_3',
			'settings' => 'vagamondo_featured_link_3_image',
			'width' => 940,
			'height' => 627,
		)));

		$wp_customize->add_setting( 'vagamondo_featured_link_3_title', array(
			'default' => '',
			'sanitize_callback' => 'sanitize_text_field',
		));

		$wp_customize->add_control( 'vagamondo_featured_link_3_title' , array(
			'type' => 'text',
			'section' => 'vagamondo_featured_link_3',
			'label' => esc_html__('Title','vagamondo'),
			'description' => esc_html__('Insert the title of this slide','vagamondo'),
		));

		$wp_customize->add_setting( 'vagamondo_featured_link_3_url', array(
			'default' => '',
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'vagamondo_featured_link_3_url' , array(
			'type' => 'url',
			'section' => 'vagamondo_featured_link_3',
			'label' => esc_html__('Url','vagamondo'),
			'description' => esc_html__('Insert the url of this slide','vagamondo'),
		));

		function vagamondo_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}
		
	}
	
	add_action( 'customize_register', 'vagamondo_customize_register', 111 );

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vagamondo_theme_setup')) {

	function vagamondo_theme_setup() {

		load_child_theme_textdomain( 'vagamondo', get_stylesheet_directory() . '/languages' );
		
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/default-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/image-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/page-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/sidebars/top-sidebar.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/sidebars/header-sidebar.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/after-content.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/post-icon.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/media.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/slick-slider.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/featured-posts-loop.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/featured-posts.php' );

		remove_theme_support( 'custom-logo');

		$defaults = array(
			'header-text' => array(
				'site-title',
				'site-description'
			)
		);
		
		add_theme_support( 'custom-logo', $defaults );

		register_default_headers( array(
			'default-image' => array(
				'url'           => get_stylesheet_directory_uri() . '/assets/images/header/header.jpg',
				'thumbnail_url' => get_stylesheet_directory_uri() . '/assets/images/header/resized-header.jpg',
				'description'   => esc_html__( 'Default image', 'vagamondo' )
			),
		));

		add_theme_support( 'custom-header', array( 
			'width'         => 1170,
			'height'        => 400,
			'default-image' => get_stylesheet_directory_uri() . '/assets/images/header/header.jpg',
			'header-text' 	=> false
		));

		remove_image_size( 'avventura_lite_slick_large');
		remove_image_size( 'avventura_lite_slick_small');

		add_image_size( 'vagamondo_slick_large', 679, 453, TRUE );
		add_image_size( 'vagamondo_post_thumbnail', 750, 643, TRUE );

		if ( !get_theme_mod('avventura_lite_menu_font_weight') )
			set_theme_mod( 'avventura_lite_menu_font_weight', '600' );

		if ( !get_theme_mod('avventura_lite_titles_font_weight') )
			set_theme_mod( 'avventura_lite_titles_font_weight', '600' );

		if ( !get_theme_mod('avventura_lite_home') )
			set_theme_mod( 'avventura_lite_home', 'right-sidebar' );

		if ( !get_theme_mod('avventura_lite_category_layout') )
			set_theme_mod( 'avventura_lite_category_layout', 'right-sidebar' );

		if ( !get_theme_mod('avventura_lite_search_layout') )
			set_theme_mod( 'avventura_lite_search_layout', 'right-sidebar' );

	}

	add_action( 'after_setup_theme', 'vagamondo_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Exclude featured posts on homepage */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vagamondo_exclude_featured_posts')) {

	function vagamondo_exclude_featured_posts(&$query) {
		
		if ( 
			$query->is_home() && 
			$query->is_main_query() &&
			avventura_lite_setting('vagamondo_sticky_post_grid','on') == 'on'
		) {
	
			$offset = 7;
			
			$ppp = get_option('posts_per_page');
		
			if ( $query->is_paged ) {
				
				$page_offset = $offset + ( ($query->query_vars['paged']-1) * $ppp );
				$query->set('offset', $page_offset );
		
			}
			else {
				$query->set('offset',$offset);
			}
	
		}
	
	}

	add_action('pre_get_posts', 'vagamondo_exclude_featured_posts', 1 );

}

/*-----------------------------------------------------------------------------------*/
/* Adjust offset pagination */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vagamondo_adjust_offset_pagination')) {

	function vagamondo_adjust_offset_pagination($found_posts, $query) {
	
		$offset = 7;
	
		if ( 
			$query->is_home() && 
			avventura_lite_setting('vagamondo_sticky_post_grid','on') == 'on'
		) {
			return $found_posts - $offset;
		}
		
		return $found_posts;
	
	}

	add_filter('found_posts', 'vagamondo_adjust_offset_pagination', 1, 2 );

}

/*-----------------------------------------------------------------------------------*/
/* VAGAMONDO IS ARCHIVE */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('vagamondo_is_archive')) {

	function vagamondo_is_archive() {

		if ( 
			is_category() ||
			is_tag() ||
			is_author() ||
			is_year() ||
			is_month()
			
		) {
		
			return true;
		
		} else {
		
			return false;
		
		}

	}

}

/*-----------------------------------------------------------------------------------*/
/* Set excerpt length */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vagamondo_excerpt_length')) {

	function vagamondo_excerpt_length($length) {

		$limit = $length;

		if ( has_post_thumbnail() ) {

			if ( 
				( is_home() && avventura_lite_setting('avventura_lite_home') == 'full' ) ||
				( vagamondo_is_archive() && avventura_lite_setting('avventura_lite_category_layout') == 'full' ) ||
				( is_search() && avventura_lite_setting('avventura_lite_search_layout') == 'full' ) 
			) {

				$limit = $length;

			} elseif ( 
				( is_home() && avventura_lite_setting('avventura_lite_home') !== 'masonry' ) ||
				( vagamondo_is_archive() && avventura_lite_setting('avventura_lite_category_layout') !== 'masonry' ) ||
				( is_search() && avventura_lite_setting('avventura_lite_search_layout') !== 'masonry' ) 
			) {

				$limit = 10;

			} else {
			
				$limit = $length;
			
			}
	
		} else {

			$limit = $length;
	
		}
	
		return $limit;
	
	}
	
	add_filter( 'excerpt_length', 'vagamondo_excerpt_length', 999 );

}

/*-----------------------------------------------------------------------------------*/
/* BODY CLASS HOOK */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('vagamondo_body_class_function')) {

	function vagamondo_body_class_function($classes) {

		if ( 
			( is_home() && avventura_lite_setting('avventura_lite_home') !== 'masonry' ) ||
			( vagamondo_is_archive() && avventura_lite_setting('avventura_lite_category_layout') !== 'masonry' ) ||
			( is_search() && avventura_lite_setting('avventura_lite_search_layout') !== 'masonry' ) 
		) :

			$classes[] = 'is_blog_section';

		endif;

		if ( 
			avventura_lite_setting('vagamondo_sticky_post_grid','on') == 'on' &&
			avventura_lite_setting('vagamondo_sticky_slideshow','on') == 'on' 
		) :
			$classes[] = 'sticky_slideshow';
		endif;
		
		return $classes;

	}

	add_filter('body_class', 'vagamondo_body_class_function');

}

/*-----------------------------------------------------------------------------------*/
/* POST CLASS HOOK */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('vagamondo_post_class_function')) {

	function vagamondo_post_class_function($classes) {

		if ( 
			( is_home() && avventura_lite_setting('avventura_lite_home') !== 'masonry' ) ||
			( vagamondo_is_archive() && avventura_lite_setting('avventura_lite_category_layout') !== 'masonry' ) ||
			( is_search() && avventura_lite_setting('avventura_lite_search_layout') !== 'masonry' ) 
		) :

			$classes[] = 'post-container-wrap';

		endif;

		return $classes;

	}

	add_filter('post_class', 'vagamondo_post_class_function');

}

?>